<?php
// tòmò web analytics
// Copyright since 2011 by Yves Goergen
// Website: http://unclassified.de/go/tomo
// Licence: GNU General Public License (GPL) Version 3
// Encoding: UTF-8 (without BOM) (auto-detect: °°°°°)
//
// This file is derived from:
// UNB Components
// Copyright since 2007 by Yves Goergen
// Website: http://unclassified.de/go/unb2
// Licence: GNU General Public License (GPL) Version 3
//
// This file contains the UNB locale de-AT class.

if (!class_exists('UnbLocale', false)) require_once dirname(__FILE__) . '/../locale.class.php';

// de-AT locale class.
//
class UnbLocale_de_AT extends UnbLocale
{
	// Locale code.
	protected $code = 'de-AT';

	// Locale importance for its language, used to sort known locales when only a language is requested.
	// This should be roughly the number of people affected by the locale, divided by 1000.
	protected $importance = 7500;   // Source: http://de.wikipedia.org/wiki/Deutsche_Sprache#Verbreitung_der_deutschen_Sprache_weltweit

	// Locale code that the locale depends on for dictionary translations.
	protected $dependsOn = 'de-DE';

	// Starting quotation mark.
	protected $quoteStart = '„';

	// Ending quotation mark.
	protected $quoteEnd = '“';

	// Colon.
	protected $colon = ':';

	// The text dictionary.
	protected $dict = array(
		);

	protected function FormatNumber($number, $decimals, $html, $trim)
	{
		$str = number_format($number, $decimals, ',', ' ');
		if ($trim && strpos($str, ',') !== false)
		{
			$str = rtrim($str, '0');
			$str = rtrim($str, ',');
		}
		if ($html)
		{
			if ($number >= 10000)
			{
				$str = str_replace(' ', "\xE2\x80\xAF" /* UTF-8: U+202F Narrow No-Break Space */, $str);
			}
			else
			{
				$str = str_replace(' ', '', $str);
			}
		}
		return $str;
	}

	protected function DoParseNumber($str, $recoveryValue)
	{
		$str = str_replace('.', '', $str);
		$str = str_replace(' ', '', $str);
		$str = str_replace(',', '.', $str);
		if (!is_numeric($str))
		{
			if (isset($recoveryValue))
				return $recoveryValue;
			throw new InvalidArgumentException('Invalid numeric value format.');
		}

		if (strpos($str, '.') !== false)
			return floatval($str);
		else
			return intval($str);
	}

	protected function FormatOrdinalNumber($number, $html)
	{
		return $number . '.';
	}

	protected function FormatTime($datetime, $details, $html)
	{
		$sp = "\xC2\xA0";   // "\xC2\xA0" = utf8_encode("\xA0")
		$lsp = "\xE2\x80\x87";   // UTF-8 for U+2007 (Figure Space, no break)

		$str = '';

		if ($details & UnbTimeFormat::Weekday)   // Mo
		{
			$str .= (strlen($str) ? $sp : '') .
				UnbLocale::Translate('weekday:' . $datetime->format('N')) .
				($details & ~UnbTimeFormat::Weekday ? ',' : '');
		}
		else if ($details & UnbTimeFormat::WeekdayLong)   // Montag
		{
			$str .= (strlen($str) ? $sp : '') .
				UnbLocale::Translate('weekdaylong:' . $datetime->format('N')) .
				($details & ~UnbTimeFormat::WeekdayLong ? ',' : '');
		}

		if ($details & UnbTimeFormat::Date)   // 01.01.2000
		{
			$str .= (strlen($str) ? $sp : '') .
				$datetime->format('d.m.Y');
			$haveDate = true;
		}
		else if ($details & UnbTimeFormat::DateLong)   // 1. Januar 2000
		{
			$str .= (strlen($str) ? $sp : '') .
				$datetime->format('j.') . $sp .
				UnbLocale::Translate('monthlong:' . $datetime->format('n')) . $sp .
				$datetime->format('Y');
			$haveDate = true;
		}

		if ($details & UnbTimeFormat::TimeSec)   // 12:15:00
		{
			$str .= (strlen($str) ? ($haveDate && $html ? $lsp : $sp) : '') .
				$datetime->format('H:i:s');
		}
		else if ($details & UnbTimeFormat::Time)   // 12:15
		{
			$str .= (strlen($str) ? ($haveDate && $html ? $lsp : $sp) : '') .
				$datetime->format('H:i');
		}

		if ($details & UnbTimeFormat::TimeZone)   // MEZ
		{
			$str .= (strlen($str) ? $sp : '') .
				UnbLocale::Translate('timezone:' . $datetime->format('T'), true);
		}

		return $str;
	}

	protected function FormatRelativeTime($diff, $context, $html)
	{
		switch ($context)
		{
			case UnbTimeContext::Point:
				if ($diff->invert)   // vor 2 Jahren
					$grammar = 2;
				else   // in 2 Jahren
					$grammar = 2;
				break;

			case UnbTimeContext::Span:
				if ($diff->invert)   // seit 2 Jahren
					$grammar = 2;
				else   // für 2 Jahre
					$grammar = 1;
				break;

			case UnbTimeContext::Before:
				if ($diff->invert)   // 2 Jahre zuvor
					$grammar = 1;
				else   // 2 Jahre später
					$grammar = 1;
				break;
		}

		$parts = array();
		if ($diff->y && count($parts) < 2)
			$parts[] = UnbLocale::NoBreak(UnbLocale::Translate('time.' . $grammar . ':years', $diff->y));
		if ($diff->m && count($parts) < 2)
			$parts[] = UnbLocale::NoBreak(UnbLocale::Translate('time.' . $grammar . ':months', $diff->m));
		if ($diff->d && count($parts) < 2)
			$parts[] = UnbLocale::NoBreak(UnbLocale::Translate('time.' . $grammar . ':days', $diff->d));
		if ($diff->h && count($parts) < 2)
			$parts[] = UnbLocale::NoBreak(UnbLocale::Translate('time.' . $grammar . ':hours', $diff->h));
		if ($diff->i && count($parts) < 2)
			$parts[] = UnbLocale::NoBreak(UnbLocale::Translate('time.' . $grammar . ':minutes', $diff->i));
		if ($diff->s && count($parts) < 2)
			$parts[] = UnbLocale::NoBreak(UnbLocale::Translate('time.' . $grammar . ':seconds', $diff->s));

		$str = '';
		foreach ($parts as $part)
		{
			$str .= (strlen($str) ? UnbLocale::Translate('time:combine') : '') .
				$part;
		}

		switch ($context)
		{
			case UnbTimeContext::Point:
				if ($diff->invert)   // vor 2 Jahren
					$str = self::Translate('time:pattern point past', 'time', $str);
				else   // in 2 Jahren
					$str = self::Translate('time:pattern point future', 'time', $str);
				break;

			case UnbTimeContext::Span:
				if ($diff->invert)   // seit 2 Jahren
					$str = self::Translate('time:pattern span past', 'time', $str);
				else   // für 2 Jahre
					$str = self::Translate('time:pattern span future', 'time', $str);
				break;

			case UnbTimeContext::Before:
				if ($diff->invert)   // 2 Jahre zuvor
					$str = self::Translate('time:pattern before past', 'time', $str);
				else   // 2 Jahre später
					$str = self::Translate('time:pattern before future', 'time', $str);
				break;
		}
		return $str;
	}

}

// Automatically register this locale
UnbLocale::Register(new UnbLocale_de_AT());

?>
